summaryrefslogtreecommitdiffstats
path: root/korn/boxcontainer.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
commit67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7 (patch)
tree5f52a9eada2e9f3654fc327d7c14dfef570a6ecb /korn/boxcontainer.h
parent2ee4bf4fd5eff93b2fbef0ff8e8063edffc5da5c (diff)
downloadtdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.tar.gz
tdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.zip
Initial conversion of kdepim to TQt
This will probably require some tweaking before it will build under Qt4, however Qt3 builds are OK. Any alterations this commit makes to kdepim behaviour under Qt3 are unintentional and should be fixed. git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1227832 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'korn/boxcontainer.h')
-rw-r--r--korn/boxcontainer.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/korn/boxcontainer.h b/korn/boxcontainer.h
index ec054318..33e1c63d 100644
--- a/korn/boxcontainer.h
+++ b/korn/boxcontainer.h
@@ -31,16 +31,17 @@ class KConfig;
* This class is the base for all BoxContainers. A BoxContainer is a place
* where BoxContainerItems can be placed. BoxContainerItems are the boxes you see.
*/
-class BoxContainer : public QObject
+class BoxContainer : public TQObject
{ Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor: everything is passed to TQObject.
*
* @param parent The parent of this object
* @param name The name of this object
*/
- BoxContainer( TQObject *parent = 0, const char * name = 0 );
+ BoxContainer( TQObject *tqparent = 0, const char * name = 0 );
/**
* Destructor
*/
@@ -31,16 +31,17 @@ class KConfig;
* Constructor: everything is passed to TQObject.
*
- * @param parent The parent of this object
+ * @param tqparent The tqparent of this object
* @param name The name of this object
*/